@@ -3,11 +3,11 @@ from ..test import ExperimentTest, Results
 
 class HasCorrectNumberOfItems(ExperimentTest):
     """Passes if a TOPUP_DTIFIT resource is found and such resource contains the
-    correct number of items (i.e. 41)."""
+    correct number of items (i.e. 50)."""
 
-    passing = 'BBRCDEV_E02823',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E02824',
-    CORRECT_NUMBER = 41
+    CORRECT_NUMBER = 50
 
     def run(self, experiment_id):
         resource_name = 'TOPUP_DTIFIT'
@@ -30,7 +30,7 @@ class HasCorrectItems(ExperimentTest):
     the expected items according to the pipeline
     [specifications](https://gitlab.com/bbrc/xnat/xnat-pipelines/-/tree/master/dtifit#outputs)."""
 
-    passing = 'BBRCDEV_E02823',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -71,7 +71,9 @@ class HasCorrectItems(ExperimentTest):
                           'topup_movpar.txt',
                           'unwarped_b0_bet_mask.nii.gz',
                           'unwarped_b0_bet.nii.gz',
-                          'unwarped_b0.nii.gz']
+                          'unwarped_b0.nii.gz',
+                          'eddyqc/qc.json',
+                          'eddyqc/qc.pdf']
 
         e = self.xnat_instance.select.experiment(experiment_id)
         res = e.resource(resource_name)
@@ -95,38 +97,43 @@ class HasCorrectItems(ExperimentTest):
         return report
 
 
-class HasCorrectANTsVersion(ExperimentTest):
-    """This test checks the version of ANTs used. Passes if TOPUP_DTIFIT outputs
-    were created using the expected version (`2.3.1.0.post149-gd15f7`)."""
+class HasCorrectMRtrix3Version(ExperimentTest):
+    """This test checks the version of MRtrix3 used. Passes if TOPUP_DTIFIT
+    outputs were created using the expected version (`3.0.2`)."""
 
-    passing = 'BBRCDEV_E02820',
-    failing = 'BBRCDEV_E00272',
+    passing = 'BBRCDEV_E02443',
+    failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
         resource_name = 'TOPUP_DTIFIT'
-        expected_version = 'ANTs Version: 2.3.1.0.post149-gd15f7'
+        expected_version = '== dwidenoise 3.0.2 =='
+
+        result = True
+        data = []
 
         e = self.xnat_instance.select.experiment(experiment_id)
-        log_file = e.resource(resource_name).file('LOGS/{}.log'.format(e.label()))
+        log = e.resource(resource_name).file('LOGS/{}.log'.format(e.label()))
+        if not log.exists():
+            msg = '{} log file not found.'.format(resource_name)
+            return Results(False, data=[msg])
 
-        if not log_file.exists():
-            return Results(False, data=['{} log file not found.'.format(resource_name)])
-
-        log_data = self.xnat_instance.get(log_file.attributes()['URI']).text
-        ants_version = [line for line in log_data.splitlines()
-                        if line.startswith('ANTs Version')][0]
-
-        if not ants_version or not ants_version.startswith(expected_version):
-            return Results(False, data=[ants_version])
+        log_data = self.xnat_instance.get(log.attributes()['URI']).text
+        version = [line for line in log_data.splitlines()
+                   if line.strip().startswith('== dwidenoise')]
+        if not version:
+            return Results(False, data=['No MRtrix3 version '
+                                        'registered in the logs.'])
+        if version[0] != expected_version:
+            return Results(False, data=version)
 
         return Results(True, data=[])
 
 
 class HasCorrectFSLVersion(ExperimentTest):
-    """This test checks the version of FSL used. Passes if TOPUP_DTIFIT outputs
-    were created using the expected version (`6.0.4:ddd0a010`)."""
+    """This test checks the version of FSL used. Passes if TOPUP_DTIFIT
+    outputs were created using the expected version (`6.0.4:ddd0a010`)."""
 
-    passing = 'BBRCDEV_E02823',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -140,11 +147,13 @@ class HasCorrectFSLVersion(ExperimentTest):
             return Results(False, data=['{} log file not found.'.format(resource_name)])
 
         log_data = self.xnat_instance.get(log_file.attributes()['URI']).text
-        fsl_version = [line for line in log_data.splitlines()
-                       if line.startswith('FSL Version')][0]
-
-        if not fsl_version or not fsl_version.startswith(expected_version):
-            return Results(False, data=[fsl_version])
+        version = [line for line in log_data.splitlines()
+                   if line.startswith('FSL Version')]
+        if not version:
+            return Results(False, data=['No FSL version '
+                                        'registered in the logs.'])
+        if not version[0].startswith(expected_version):
+            return Results(False, data=version)
 
         return Results(True, data=[])
 
@@ -154,7 +163,7 @@ class DTIFITSnapshotFA(ExperimentTest):
     generated by TOPUP_DTIFIT. Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02820',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E00272',
 
     def run(self, experiment_id):
@@ -182,12 +191,9 @@ class DTIFITSnapshotFA(ExperimentTest):
             fd, path = tempfile.mkstemp(suffix='.jpg')
             os.close(fd)
             paths.append(path)
-            im = plotting.plot_stat_map(fa_fp,
-                                        draw_cross=False,
-                                        black_bg=True,
-                                        bg_img=None,
-                                        display_mode=each,
-                                        cut_coords=10)
+            im = plotting.plot_stat_map(fa_fp, draw_cross=False,
+                                        black_bg=True, bg_img=None,
+                                        display_mode=each, cut_coords=10)
             im.savefig(path)
 
         return Results(True, data=paths)
@@ -208,7 +214,7 @@ class DTIFITSnapshotRGB(ExperimentTest):
     generated by TOPUP_DTIFIT. Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02820',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E00272',
 
     def run(self, experiment_id):
@@ -281,6 +287,7 @@ class DTIFITSnapshotRGB(ExperimentTest):
                     transparent=True,
                     pad_inches=0)
 
+        os.remove(v1_fp)
         return Results(True, data=paths)
 
     def report(self):
@@ -300,7 +307,7 @@ class DTIFITSnapshotTOPUP(ExperimentTest):
     original image (green colormap). Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02823',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -350,9 +357,9 @@ class HasFewNegativeVoxelsInMD(ExperimentTest):
     may propagate to pipeline resulting maps, presenting an abnormal amount of
     voxels with negative values. This test counts the voxels with negative values
     the Mean Diffusivity (MD) map has. Fails if the number of negative voxels
-    found is higher than 500. Passes otherwise."""
+    found is higher than 2000. Passes otherwise."""
 
-    passing = 'BBRCDEV_E02823',
+    passing = 'BBRCDEV_E02443',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -360,7 +367,7 @@ class HasFewNegativeVoxelsInMD(ExperimentTest):
         import tempfile
 
         resource_name = 'TOPUP_DTIFIT'
-        negative_voxels_threshold = 500
+        negative_voxels_threshold = 2000
 
         e = self.xnat_instance.select.experiment(experiment_id)
         r = e.resource(resource_name)
@@ -393,3 +400,81 @@ class HasFewNegativeVoxelsInMD(ExperimentTest):
             report.append('MD map has {} voxels with negative values.'
                           .format(self.results.data[0]))
         return report
+
+
+class HasAcceptableAverageSNR(ExperimentTest):
+    """This test checks the voxel-wise SNR for b=0 volumes (i.e. volumes with no
+    diffusion weighting) calculated by `eddy` and averaged across all voxels within
+    the brain mask as a summary measure of overall data quality. Test passes if
+    SNR > 20. Fails otherwise."""
+
+    passing = 'BBRCDEV_E02443',
+    failing = 'BBRCDEV_E02824',
+    resource_name = 'TOPUP_DTIFIT'
+    eddyqc_file = 'eddyqc/qc.json'
+
+    def eddyqc_data(self, experiment_id):
+        e = self.xnat_instance.select.experiment(experiment_id)
+        f = e.resource(self.resource_name).file(self.eddyqc_file)
+        if not f.exists():
+            return None
+
+        qc_data = self.xnat_instance.get(f.attributes()['URI']).json()
+        return qc_data
+
+    def run(self, experiment_id):
+        qc_data = self.eddyqc_data(experiment_id)
+        if not qc_data:
+            return Results(False, data=['`{}` file not found.'
+                                        ''.format(self.eddyqc_file)])
+        avg_snr = qc_data['qc_cnr_avg'][0]
+        if avg_snr < 20.0:
+            data = ['Average SNR (b=0): {}'.format(avg_snr)]
+            return Results(False, data)
+
+        return Results(True, [])
+
+
+class HasAcceptableAverageCNR(HasAcceptableAverageSNR):
+    __doc__ = """This test checks the voxel-wise CNR for b=1300 volumes 
+    (i.e. diffusion weighted volumes) calculated by `eddy` and averaged across 
+    all voxels within the brain mask as a summary measure of the level of angular 
+    contrast (i.e. higher CNR improves the estimation of complex fibre 
+    configurations). Test passes if CNR > 2.5. Fails otherwise."""
+
+    passing = 'BBRCDEV_E02443',
+    failing = 'BBRCDEV_E02824',
+
+    def run(self, experiment_id):
+        qc_data = self.eddyqc_data(experiment_id)
+        if not qc_data:
+            return Results(False, data=['`{}` file not found.'
+                                        ''.format(self.eddyqc_file)])
+        avg_cnr = qc_data['qc_cnr_avg'][1]
+        if avg_cnr < 2.5:
+            data = ['Average CNR (b=1300): {}'.format(avg_cnr)]
+            return Results(False, data)
+
+        return Results(True, [])
+
+
+class HasAcceptableOutliersPercentage(HasAcceptableAverageSNR):
+    __doc__ = """This test checks the total number of outlier slices 
+    (i.e. slices affected by severe signal dropout) detected by `eddy`. 
+    Test passes if the percentage of outliers found is lower than 1%. 
+    Fails otherwise."""
+
+    passing = 'BBRCDEV_E02443',
+    failing = 'BBRCDEV_E02824',
+
+    def run(self, experiment_id):
+        qc_data = self.eddyqc_data(experiment_id)
+        if not qc_data:
+            return Results(False, data=['`{}` file not found.'
+                                        ''.format(self.eddyqc_file)])
+        outliers = qc_data['qc_outliers_tot']
+        if outliers > 1.0:
+            data = ['Total outliers (%): {}'.format(outliers)]
+            return Results(False, data)
+
+        return Results(True, [])
