@@ -396,26 +396,10 @@ class ReconAllAsegSnapshot(ExperimentTest, Snapshot):
     threshold = 75
 
     def run(self, experiment_id):
-
-        if os.getenv('SKIP_SNAPSHOTS_TESTS') == 'True':
-            return Results(experiment_id == self.passing[0],
-                           data=['Skipping it. (SKIP_SNAPSHOTS_TESTS)'])
-        try:
-            snap_fp = self.snap(experiment_id)
-        except Exception:
-            return Results(False, data=['Snapshot creation failed.'])
-
-        return Results(True, data=[snap_fp])
+        return Snapshot.run(self, experiment_id)
 
     def report(self):
-        report = []
-        if self.results.has_passed:
-            path = self.results.data[0]
-            report.append('![snapshot](%s)' % path)
-        else:
-            report = self.results.data
-
-        return report
+        return Snapshot.report(self)
 
 
 class ReconAllAparcSnapshot(ExperimentTest, Snapshot):
@@ -437,30 +421,14 @@ class ReconAllAparcSnapshot(ExperimentTest, Snapshot):
     threshold = 75
 
     def run(self, experiment_id):
-
-        if os.getenv('SKIP_SNAPSHOTS_TESTS') == 'True':
-            return Results(experiment_id == self.passing[0],
-                           data=['Skipping it. (SKIP_SNAPSHOTS_TESTS)'])
-        try:
-            snap_fp = self.snap(experiment_id)
-
-        except Exception:
-            return Results(False, data=['Snapshot creation failed.'])
-        return Results(True, data=[snap_fp])
+        return Snapshot.run(self, experiment_id)
 
     def report(self):
-        report = []
-        if self.results.has_passed:
-            path = self.results.data[0]
-            report.append('![snapshot](%s)' % path)
-        else:
-            report = self.results.data
-
-        return report
+        return Snapshot.report(self)
 
 
 class AreCAVolumesConsistent(ExperimentTest):
-    """Checks that CA1, CA2 and CA3 (_Cornu Ammonis_ areas) display the  
+    """Checks that CA1, CA2 and CA3 (_Cornu Ammonis_ areas) display the
     expected order in volumes in the resulting segmentation.
     consistent in size. Passes if `CA1` > `CA4` > `CA3` and fails otherwise."""
 
