@@ -75,11 +75,9 @@ class HasCorrectSPMVersion(ExperimentTest):
     passing = 'BBRCDEV_E00272',
     failing = 'BBRCDEV_E00251',
     resource_name = 'SPM12_SEGMENT'
+    expected_version = 'SPM version: SPM12 Release: 7219'
 
     def run(self, experiment_id):
-        expected_version = 'SPM version: SPM12 Release: 7219'
-        result = True
-        msg = []
 
         data = self.xnat_instance.array.experiments(experiment_id=experiment_id,
                                                     columns=['label']).data
@@ -97,11 +95,13 @@ class HasCorrectSPMVersion(ExperimentTest):
         spm_version = [line for line in log_data.splitlines()
                        if line.startswith('SPM version:')]
 
-        if not spm_version or spm_version[0] != expected_version:
-            result = False
-            msg.append('Incorrect SPM version: {}'.format(expected_version))
+        if not spm_version:
+            return Results(False, data=['No SPM version '
+                                        'registered in the logs.'])
+        elif list(set(spm_version)) != [self.expected_version]:
+            return Results(False, data=list(set(spm_version)))
 
-        return Results(result, data=msg)
+        return Results(True, [])
 
 
 class HasCorrectMatlabVersion(ExperimentTest):
@@ -215,7 +215,7 @@ class SPM12SegmentSnapshot(ExperimentTest):
                                               self.resource_name)
 
             # Create snapshot with proper options
-            fd, snap_fp = tempfile.mkstemp(suffix=snap.format)
+            fd, snap_fp = tempfile.mkstemp(suffix=snap.__format__)
             os.close(fd)
             snap.plot_segment(filepaths, axes=axes, bg=bg, opacity=70,
                               slices=slices, animated=False, savefig=snap_fp,
@@ -247,6 +247,7 @@ class HasNormalSPM12Volumes(ExperimentTest):
     passing = 'BBRCDEV_E00559',
     failing = 'BBRCDEV_E01613',
     resource_name = 'SPM12_SEGMENT'
+    file_prefixes = ['c1', 'c2', 'c3']
 
     def check(self, vols):
         boundaries = [('c1', [480000, 900000]),
@@ -263,6 +264,7 @@ class HasNormalSPM12Volumes(ExperimentTest):
         import tempfile
         import nibabel as nib
         import numpy as np
+        import os
 
         e = self.xnat_instance.select.experiment(experiment_id)
         r = e.resource(self.resource_name)
@@ -270,9 +272,10 @@ class HasNormalSPM12Volumes(ExperimentTest):
             return Results(False, data=['Missing {} resource'
                                         .format(self.resource_name)])
         vols = []
-        _, fp = tempfile.mkstemp(suffix='.nii.gz')
+        fd, fp = tempfile.mkstemp(suffix='.nii.gz')
+        os.close(fd)
 
-        for kls in ['c1', 'c2', 'c3']:
+        for kls in self.file_prefixes:
             try:
                 f = [each for each in r.files() if each.id().startswith(kls)][0]
             except IndexError:
@@ -284,6 +287,7 @@ class HasNormalSPM12Volumes(ExperimentTest):
             v = np.sum(d.dataobj) * size
             vols.append(v)
 
+        os.remove(fp)
         res = self.check(vols)
         return Results(res, data=['Volumes: {} {}'.format(vols[0], vols[1])])
 
