@@ -1140,7 +1140,7 @@ class IsPhilipsVersion519(ExperimentTest):
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E00401',
-    mri_philips_version = ['5.1.9', '5.1.9.1']
+    mri_philips_version = '5.1.9'
 
     def run(self, experiment_id):
         cols = ['ID', 'label', 'project', 'subject_ID']
@@ -1162,10 +1162,7 @@ class IsPhilipsVersion519(ExperimentTest):
 
         result = False
         data = ['Unexpected version: %s' % tag_value]
-        if len(tag_value) == 2 and tag_value == self.mri_philips_version:
-            result = True
-            data = []
-        elif len(tag_value) == 1 and tag_value[0] in self.mri_philips_version:
+        if tag_value[0] == self.mri_philips_version:
             result = True
             data = []
         return Results(result, data)
@@ -1177,7 +1174,7 @@ class IsPhilipsVersion540(IsPhilipsVersion519):
 
     passing = 'BBRCDEV_E00401',
     failing = 'BBRCDEV_E00272',
-    mri_philips_version = ['5.4.0', '5.4.0.0']
+    mri_philips_version = '5.4.0'
 
 
 class IsPhilipsVersion561(IsPhilipsVersion519):
@@ -1186,7 +1183,7 @@ class IsPhilipsVersion561(IsPhilipsVersion519):
 
     passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E00401',
-    mri_philips_version = ['5.6.1', '5.6.1.2']
+    mri_philips_version = '5.6.1'
 
 
 class IsAccessionNumberUnique(ExperimentTest):
@@ -1719,3 +1716,48 @@ class IsBASILRunnable(IsFreeSurferRunnable):
     passing = 'BBRCDEV_E00276',
     failing = 'BBRCDEV_E00013',
     tests = [HasUsableT1, HasUsableASL, HasUsableM0]
+
+
+class HasUsableRS(HasUsableDWI):
+    passing = 'BBRCDEV_E02823',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'RS'
+    required_tests = [IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Resting State fMRI')
+    __doc__ = __doc__.replace('DWI', 'RS-fMRI')
+
+
+class HasUsableSEap(HasUsableDWI):
+    passing = 'BBRCDEV_E02823',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'SEap'
+    required_tests = [IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Spin-echo fMRI with AP '
+                                           'phase-encoding')
+    __doc__ = __doc__.replace('DWI', 'SE-fMRI-AP')
+
+
+class HasUsableSEpa(HasUsableDWI):
+    passing = 'BBRCDEV_E02823',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'SEpa'
+    required_tests = [IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Spin-echo fMRI with PA '
+                                           'phase-encoding')
+    __doc__ = __doc__.replace('DWI', 'SE-fMRI-PA')
+
+
+class IsFMRIPrepRunnable(IsFreeSurferRunnable):
+    """This test checks that a given MRSession fulfills the requirements to run
+    `fMRIPrep`, a multimodal pipeline that prepares Resting State fMRI data for
+    a variety of posterior analyses. `FMRIPREP` requires a T1w image, a Resting
+    State fMRI image and a couple of Spin-echo scans with reversed phase-encoding
+    polarity to run. This test passes if the right scan images can be found,
+    fails otherwise."""
+
+    passing = 'BBRCDEV_E02823',
+    failing = 'BBRCDEV_E00013',
+    tests = [HasUsableT1, HasUsableRS, HasUsableSEap, HasUsableSEpa]
\ No newline at end of file
