@@ -151,7 +151,11 @@ class ArchivingValidator(Validator):
                  data.IsBAMOSRunnable,
                  data.HasUsableASL,
                  data.HasUsableM0,
-                 data.IsBASILRunnable]
+                 data.IsBASILRunnable,
+                 data.HasUsableRS,
+                 data.HasUsableSEap,
+                 data.HasUsableSEpa,
+                 data.IsFMRIPrepRunnable]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -305,7 +309,8 @@ class SPM12SegmentT1T2Validator(Validator):
                  spm_t1t2.SPM12SegmentSnapshot,
                  spm_t1t2.HasNormalSPM12Volumes,
                  spm_t1t2.SPM12SegmentExecutionTime,
-                 spm_t1t2.SPM12SegmentMultichannelHoles]
+                 spm_t1t2.SPM12SegmentMultichannelHoles,
+                 spm_t1t2.SPM12SegmentMultichannelClusters]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -428,3 +433,11 @@ class FreeSurfer7ExtrasValidator(Validator):
                  fs7_extras.HypothalamusSnapshot,
                  fs7_extras.ThalamusNucleiSnapshot]
         super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class DickersonValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import dickerson
+        tests = [dickerson.HasCorrectItems,
+                 dickerson.HasCorrectFreeSurferVersion]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
\ No newline at end of file
